/**
 *******************************************************************************
 * @file    main.c
 *
 * @brief   Main program body.
 *
 * @author  DPM
 *
 * @version V1.0.0
 *
 * @date    2024-5-6
 *
 *******************************************************************************/

/*
    Copyright (c) 2024, DP Microelectronics Inc.

    Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice, this
       list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
    3. Neither the name of the copyright holder nor the names of its contributors
       may be used to endorse or promote products derived from this software without
       specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

/* Files include */
#include "main.h"
#include "dpm32m0xx.h"
#include "dpm32m0xx_eval.h"
#include "rs485.h"
#include "systick.h"
#include <stdio.h>

/**
  * @addtogroup DPM32M08X_LibSamples
  * @{
  */

/**
  * @addtogroup UART
  * @{
  */

/**
  * @addtogroup UART_485_MasterInterrupt
  * @{
  */

/* Private typedef --------------------------------------------------------------*/

/* Private define ---------------------------------------------------------------*/
#define sendlen 5

/* Private macro ----------------------------------------------------------------*/

/* Private variables ------------------------------------------------------------*/
uint16_t receivelen;
uint8_t i = 0;
uint8_t cnt = 0;
uint8_t tx485buf[16];
uint8_t rx485buf[16];

/* Private functions ------------------------------------------------------------*/

/**
  * @brief  The program entry function.
  * @retval int
  */
int main(void)
{
  /* Configure the system clock */
  SystemClockInit();
  /* Configure the system tick */
  SystickInit();

  /* Led Init */
  EVAL_LedInit(LED1);

  /* Print Uart Init */
  EVAL_ComInit();
  
  /* Key Init */
  EVAL_KeyInit(KEY_UP, KEY_MODE_GPIO);

  /********************* Operation  *********************/
  /* UART1 Init */
  RS485_Init();

  uint32_t ledTime = 0;
  printf("UART1 485 test example\r\n");
  while(1)
  {
    /* KEY_UP pressed to send data once */
    if(SET == EVAL_KeyStateGet(KEY_UP))
    {
      DelayMs(10);

      if(SET == EVAL_KeyStateGet(KEY_UP))
      {
        for(i = 0; i < sendlen; i++)
        {
          /* Fill the send buffer */
          tx485buf[i] = cnt*i;
        }

        RS485_Send_Data(tx485buf, sendlen, 1000);

        RS485_Receive_Data(rx485buf, &receivelen);
        DelayMs(10);
        cnt++;
      }
    }

    /* Runing led toggle */
    if(ledTime < GetTick())
    {
      ledTime = GetTick() + 1000;
      EVAL_LedToggle(LED1);
    }
  }
}

/* retarget the C library printf function to the usart */
int fputc(int ch, FILE *f)
{
  UART_SendData(EVAL_COM0, (uint8_t)ch);

  while(RESET == UART_GetIntFlagStatus(EVAL_COM0, UART_INT_FLAG_TXE));

  return ch;
}


/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) COPYRIGHT DP *****END OF FILE ***************************/
